==> quarkus-smallrye-metrics-deployment-1.8.1.Final-sources.jar: io/quarkus/smallrye/metrics/deployment/SmallRyeMetricsProcessor$SmallRyeMetricsConfig$$accessor.java <==
package io.quarkus.smallrye.metrics.deployment;
public final class SmallRyeMetricsProcessor$SmallRyeMetricsConfig$$accessor {
    private SmallRyeMetricsProcessor$SmallRyeMetricsConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_path(Object __instance) {
        return ((io.quarkus.smallrye.metrics.deployment.SmallRyeMetricsProcessor.SmallRyeMetricsConfig)__instance).path;
    }
    @SuppressWarnings("unchecked")
    public static void set_path(Object __instance, Object path) {
        ((io.quarkus.smallrye.metrics.deployment.SmallRyeMetricsProcessor.SmallRyeMetricsConfig)__instance).path = (String)path;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_extensionsEnabled(Object __instance) {
        return ((io.quarkus.smallrye.metrics.deployment.SmallRyeMetricsProcessor.SmallRyeMetricsConfig)__instance).extensionsEnabled;
    }
    @SuppressWarnings("unchecked")
    public static void set_extensionsEnabled(Object __instance, boolean extensionsEnabled) {
        ((io.quarkus.smallrye.metrics.deployment.SmallRyeMetricsProcessor.SmallRyeMetricsConfig)__instance).extensionsEnabled = extensionsEnabled;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_micrometerCompatibility(Object __instance) {
        return ((io.quarkus.smallrye.metrics.deployment.SmallRyeMetricsProcessor.SmallRyeMetricsConfig)__instance).micrometerCompatibility;
    }
    @SuppressWarnings("unchecked")
    public static void set_micrometerCompatibility(Object __instance, boolean micrometerCompatibility) {
        ((io.quarkus.smallrye.metrics.deployment.SmallRyeMetricsProcessor.SmallRyeMetricsConfig)__instance).micrometerCompatibility = micrometerCompatibility;
    }
    public static Object construct() {
        return new io.quarkus.smallrye.metrics.deployment.SmallRyeMetricsProcessor.SmallRyeMetricsConfig();
    }
}

==> quarkus-smallrye-metrics-deployment-2.16.8.Final-sources.jar: io/quarkus/smallrye/metrics/deployment/SmallRyeMetricsProcessor$SmallRyeMetricsConfig$$accessor.java <==
package io.quarkus.smallrye.metrics.deployment;
public final class SmallRyeMetricsProcessor$SmallRyeMetricsConfig$$accessor {
    private SmallRyeMetricsProcessor$SmallRyeMetricsConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_path(Object __instance) {
        return ((io.quarkus.smallrye.metrics.deployment.SmallRyeMetricsProcessor.SmallRyeMetricsConfig)__instance).path;
    }
    @SuppressWarnings("unchecked")
    public static void set_path(Object __instance, Object path) {
        ((io.quarkus.smallrye.metrics.deployment.SmallRyeMetricsProcessor.SmallRyeMetricsConfig)__instance).path = (String)path;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_extensionsEnabled(Object __instance) {
        return ((io.quarkus.smallrye.metrics.deployment.SmallRyeMetricsProcessor.SmallRyeMetricsConfig)__instance).extensionsEnabled;
    }
    @SuppressWarnings("unchecked")
    public static void set_extensionsEnabled(Object __instance, boolean extensionsEnabled) {
        ((io.quarkus.smallrye.metrics.deployment.SmallRyeMetricsProcessor.SmallRyeMetricsConfig)__instance).extensionsEnabled = extensionsEnabled;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_micrometerCompatibility(Object __instance) {
        return ((io.quarkus.smallrye.metrics.deployment.SmallRyeMetricsProcessor.SmallRyeMetricsConfig)__instance).micrometerCompatibility;
    }
    @SuppressWarnings("unchecked")
    public static void set_micrometerCompatibility(Object __instance, boolean micrometerCompatibility) {
        ((io.quarkus.smallrye.metrics.deployment.SmallRyeMetricsProcessor.SmallRyeMetricsConfig)__instance).micrometerCompatibility = micrometerCompatibility;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_jaxrsEnabled(Object __instance) {
        return ((io.quarkus.smallrye.metrics.deployment.SmallRyeMetricsProcessor.SmallRyeMetricsConfig)__instance).jaxrsEnabled;
    }
    @SuppressWarnings("unchecked")
    public static void set_jaxrsEnabled(Object __instance, boolean jaxrsEnabled) {
        ((io.quarkus.smallrye.metrics.deployment.SmallRyeMetricsProcessor.SmallRyeMetricsConfig)__instance).jaxrsEnabled = jaxrsEnabled;
    }
    public static Object construct() {
        return new io.quarkus.smallrye.metrics.deployment.SmallRyeMetricsProcessor.SmallRyeMetricsConfig();
    }
}
